// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
package user_update

import (
    "encoding/json"
    "testing"

    "github.com/twitchdev/twitch-cli/internal/events"
    "github.com/twitchdev/twitch-cli/internal/models"
    "github.com/twitchdev/twitch-cli/test_setup"
)

var toUser = "4567"

func TestEventSub(t *testing.T) {
    a := test_setup.SetupTestEnv(t)

    params := *&events.MockEventParameters{
        ToUserID:     toUser,
        Transport:  models.TransportEventSub,
        Trigger:    "user.update",
    }

    r, err := Event{}.GenerateEvent(params)
    a.Nil(err)

    var body models.StreamUpEventSubResponse
    err = json.Unmarshal(r.JSON, &body)
    a.Nil(err)

    // write actual tests here (making sure you set appropriate values and the like) for eventsub
}

func TestFakeTransport(t *testing.T) {
    a := test_setup.SetupTestEnv(t)

    params := *&events.MockEventParameters{
        ToUserID:     toUser,
        Transport:  "fake_transport",
        Trigger:    "unsubscribe",
    }

    r, err := Event{}.GenerateEvent(params)
    a.Nil(err)
    a.Empty(r)
}
func TestValidTrigger(t *testing.T) {
    a := test_setup.SetupTestEnv(t)

    r := Event{}.ValidTrigger("user.update")
    a.Equal(true, r)

    r = Event{}.ValidTrigger("notgift")
    a.Equal(false, r)
}

func TestValidTransport(t *testing.T) {
    a := test_setup.SetupTestEnv(t)

    r := Event{}.ValidTransport(models.TransportEventSub)
    a.Equal(true, r)

    r = Event{}.ValidTransport("noteventsub")
    a.Equal(false, r)
}
func TestGetTopic(t *testing.T) {
    a := test_setup.SetupTestEnv(t)

    r := Event{}.GetTopic(models.TransportEventSub, "user.update")
    a.NotNil(r)
}
